# Crypton

## Affine & Block Cypher Implementations With Python

![Tests](https://github.com/batuhaninan/Crypton/actions/workflows/tests.yml/badge.svg)

## Python

You need Python 3.7+ to use Crypton

## Install Dependencies
```bash
pip install .
```

## Install Dev Dependencies (for running tests)
```bash
pip install -r requirements_dev.txt
```

## Run Tests
```bash
pytest
```


## Authors

* [Batuhan INAN](https://github.com/batuhaninan)
* [Atilla Basaran](https://github.com/atilla525)
